@@ -421,9 +421,9 @@ def test_form_required_local_message(app, sqlalchemy_datastore):
     assert b"Key" not in response.data
 
 
+@pytest.mark.app_settings(babel_default_locale="fr_FR")
 def test_without_babel(app, client):
     # Test if babel modules exist but we don't init babel - things still work
-    app.config["BABEL_DEFAULT_LOCALE"] = "fr_FR"
     response = client.get("/login")
     assert response.status_code == 200
 
@@ -442,7 +442,6 @@ def test_no_email_sender(app, sqlalchemy_datastore):
     security.init_app(app, sqlalchemy_datastore)
 
     with app.app_context():
-        app.try_trigger_before_first_request_functions()
         user = TestUser("matt@lp.com")
         with app.mail.record_messages() as outbox:
             send_mail("Test Default Sender", user.email, "welcome", user=user)
@@ -464,7 +463,6 @@ def test_sender_tuple(app, sqlalchemy_datastore):
     security.init_app(app, sqlalchemy_datastore)
 
     with app.app_context():
-        app.try_trigger_before_first_request_functions()
         user = TestUser("matt@lp.com")
         with app.mail.record_messages() as outbox:
             send_mail("Test Tuple Sender", user.email, "welcome", user=user)
@@ -472,9 +470,9 @@ def test_sender_tuple(app, sqlalchemy_datastore):
             assert "Test User <test@testme.com>" == outbox[0].sender
 
 
+@pytest.mark.app_settings(babel_default_locale="fr_FR")
 @pytest.mark.babel()
 def test_xlation(app, client):
-    app.config["BABEL_DEFAULT_LOCALE"] = "fr_FR"
     assert check_xlation(app, "fr_FR"), "You must run python setup.py compile_catalog"
 
     response = client.get("/login")
@@ -486,6 +484,7 @@ def test_xlation(app, client):
 
 
 @pytest.mark.babel()
+@pytest.mark.app_settings(babel_default_locale="fr_FR")
 def test_myxlation(app, sqlalchemy_datastore, pytestconfig):
     # Test changing a single MSG and having an additional translation dir
     # Flask-BabelEx doesn't support lists of directories..
@@ -504,7 +503,6 @@ def test_myxlation(app, sqlalchemy_datastore, pytestconfig):
         app, sqlalchemy_datastore, **{"SECURITY_I18N_DIRNAME": i18n_dirname}
     )
 
-    app.config["BABEL_DEFAULT_LOCALE"] = "fr_FR"
     assert check_xlation(app, "fr_FR"), "You must run python setup.py compile_catalog"
 
     app.config["SECURITY_MSG_INVALID_PASSWORD"] = ("Password no-worky", "error")
@@ -515,8 +513,8 @@ def test_myxlation(app, sqlalchemy_datastore, pytestconfig):
 
 
 @pytest.mark.babel()
+@pytest.mark.app_settings(babel_default_locale="fr_FR")
 def test_form_labels(app, sqlalchemy_datastore):
-    app.config["BABEL_DEFAULT_LOCALE"] = "fr_FR"
     app.security = Security()
     app.security.init_app(app, sqlalchemy_datastore)
     assert check_xlation(app, "fr_FR"), "You must run python setup.py compile_catalog"
@@ -542,6 +540,7 @@ def test_form_labels(app, sqlalchemy_datastore):
 
 
 @pytest.mark.babel()
+@pytest.mark.app_settings(babel_default_locale="fr_FR")
 def test_wtform_xlation(app, sqlalchemy_datastore):
     # Make sure wtform xlations work
     class MyLoginForm(LoginForm):
@@ -549,7 +548,6 @@ def test_wtform_xlation(app, sqlalchemy_datastore):
             "FixedLength", validators=[DataRequired(), Length(3, 3)]
         )
 
-    app.config["BABEL_DEFAULT_LOCALE"] = "fr_FR"
     app.security = Security()
     app.security.init_app(app, datastore=sqlalchemy_datastore, login_form=MyLoginForm)
     assert check_xlation(app, "fr_FR"), "You must run python setup.py compile_catalog"
@@ -579,7 +577,6 @@ def test_per_request_xlate(app, client):
 
     babel = app.extensions["babel"]
 
-    @babel.localeselector
     def get_locale():
         # For a given session - set lang based on first request.
         # Honor explicit url request first
@@ -591,6 +588,9 @@ def test_per_request_xlate(app, client):
                 session["lang"] = locale
         return session.get("lang", None).replace("-", "_")
 
+    babel.locale_selector_func = get_locale
+    babel.locale_selector = get_locale  # Flask-Babel >= 3.0.0
+
     response = client.get("/login", headers=[("Accept-Language", "fr")])
     assert b'<label for="password">Mot de passe</label>' in response.data
     # make sure template contents get xlated (not just form).
@@ -650,7 +650,6 @@ def test_zxcvbn_xlate(app):
 @pytest.mark.skipif(sys.version_info < (3, 0), reason="requires python3 or higher")
 @pytest.mark.settings(password_check_breached="strict")
 def test_breached(app, sqlalchemy_datastore):
-
     # partial response from: https://api.pwnedpasswords.com/range/07003
     pwned_response = b"AF5A73CD3CBCFDCD12B0B68CB7930F3E888:2\r\n\
 AFD8AA47E6FD782ADDC11D89744769F7354:2\r\n\
@@ -679,7 +678,6 @@ B3902FD808DCA504AAAD30F3C14BD3ACE7C:10"
     password_complexity_checker="zxcvbn",
 )
 def test_breached_cnt(app, sqlalchemy_datastore):
-
     # partial response from: https://api.pwnedpasswords.com/range/07003
     pwned_response = b"AF5A73CD3CBCFDCD12B0B68CB7930F3E888:2\r\n\
 AFD8AA47E6FD782ADDC11D89744769F7354:2\r\n\
