@@ -37,7 +37,6 @@ def test_registerable_flag(clients, app, get_message):
     # Test registering is successful, sends email, and fires signal
     @user_registered.connect_via(app)
     def on_user_registered(app, **kwargs):
-
         assert isinstance(app, Flask)
         assert isinstance(kwargs["user"], UserMixin)
         assert kwargs["confirm_token"] is None
@@ -117,9 +116,9 @@ def test_registerable_flag(clients, app, get_message):
 
 @pytest.mark.confirmable()
 @pytest.mark.babel()
+@pytest.mark.app_settings(babel_default_locale="fr_FR")
 def test_xlation(app, client, get_message_local):
     # Test form and email translation
-    app.config["BABEL_DEFAULT_LOCALE"] = "fr_FR"
     assert check_xlation(app, "fr_FR"), "You must run python setup.py compile_catalog"
 
     response = client.get("/register", follow_redirects=True)
@@ -302,7 +301,6 @@ def test_form_data_is_passed_to_user_registered_signal(app, sqlalchemy_datastore
 
     @user_registered.connect_via(app)
     def on_user_registered(app, **kwargs):
-
         assert isinstance(app, Flask)
         assert isinstance(kwargs["user"], UserMixin)
         assert kwargs["confirm_token"] is None
